package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jun 20, 2024
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Request struct {
CaptchaToken string `form:"captchaResponse" json:"captchaResponse" validate:"required"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.